﻿### This Script sets all the Regional Informations in Sharepoint Sites  ####
### and changes the Default Regional Settings for all new SP-Sites      ####

# Insert the credentials and the name of the admin site
$Username="admin@tenantname.onmicrosoft.com"
$AdminPassword=Read-Host -Prompt "Password" -AsSecureString
$creds=New-Object System.Management.Automation.PSCredential($Username,$AdminPassword)
Connect-SPOService https://tenantname-admin.sharepoint.com -Credential $creds

function Set-SPOSitesRegionalSettings
{
  
   param (
        [Parameter(Mandatory=$true,Position=1)]
		[string]$Username,
		[Parameter(Mandatory=$true,Position=2)]
		$AdminPassword,
        [Parameter(Mandatory=$true,Position=3)]
		[string]$Url,
        [Parameter(Mandatory=$true,Position=4)]
		[string]$TimeZoneID,
        [Parameter(Mandatory=$true,Position=5)]
		[string]$LocaleID,
        [Parameter(Mandatory=$true,Position=6)]
   		[string]$WorkDayStartHour,
        [Parameter(Mandatory=$true,Position=7)]
		[string]$WorkDayEndHour,
        [Parameter(Mandatory=$true,Position=8)]
		[string]$FirstDayOfWeek,
        [Parameter(Mandatory=$true,Position=9)]
		[string]$Time24,
        [Parameter(Mandatory=$true,Position=10)]
		[string]$CalendarType,
        [Parameter(Mandatory=$true,Position=11)]
		[string]$AlternateCalendarType,
        [Parameter(Mandatory=$true,Position=12)]
		[string]$WorkDays
		)
  
    $ctx=New-Object Microsoft.SharePoint.Client.ClientContext($Url)
    $ctx.Credentials = New-Object Microsoft.SharePoint.Client.SharePointOnlineCredentials($Username, $AdminPassword)

    try
    {
        $ctx.ExecuteQuery() 
    }
    catch
    {
        Write-Host "Could not authenticate to " $Url -ForegroundColor Red
        return;
    }  

    $ctx.Load($ctx.Web.RegionalSettings)
    $ctx.Load($ctx.Web.RegionalSettings.TimeZone)
    $ctx.Load($ctx.Web.RegionalSettings.TimeZones)    

    try
    {
        $ctx.ExecuteQuery()  
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.TimeZone.Id 
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.LocaleId 
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.WorkDayStartHour
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.WorkDayEndHour 
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.FirstDayOfWeek
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.Time24
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.CalendarType
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.AlternateCalendarType 
        Write-Host "Current regional settings: $url" $ctx.Web.RegionalSettings.WorkDays
    }
    catch
    {
        Write-Host "Could not load current regional settings" -ForegroundColor Red
    }

    $ctx.Web.RegionalSettings.TimeZone=$ctx.Web.RegionalSettings.TimeZones.GetbyID($TimeZoneID)
    $ctx.Web.RegionalSettings.LocaleId=$LocaleId
    $ctx.Web.RegionalSettings.WorkDayStartHour=$WorkDayStartHour
    $ctx.Web.RegionalSettings.WorkDayEndHour=$WorkDayEndHour
    $ctx.Web.RegionalSettings.FirstDayOfWeek=$FirstDayOfWeek
    $ctx.Web.RegionalSettings.Time24=$Time24
    $ctx.Web.RegionalSettings.CalendarType=$CalendarType
    $ctx.Web.RegionalSettings.AlternateCalendarType=$AlternateCalendarType
    $ctx.Web.RegionalSettings.WorkDays=$WorkDays

    $ctx.Web.Update()

    try
    {
        $ctx.ExecuteQuery()
        Write-Host "...Updated regional settings" -ForegroundColor Green
    }
    catch
    {
        Write-Host -Separator "Could not update regional settings $Url" $_.Exception.Message -ForegroundColor Red
    }

}
     

# Paths to SDK. Please verify location on your computer.
Add-Type -Path "C:\Program Files\Common Files\microsoft shared\Web Server Extensions\16\ISAPI\Microsoft.SharePoint.Client.dll" 
Add-Type -Path "C:\Program Files\Common Files\microsoft shared\Web Server Extensions\16\ISAPI\Microsoft.SharePoint.Client.Runtime.dll" 



# Set the Variables
$TimeZoneID=4                     # list of time zones: https://msdn.microsoft.com/library/microsoft.sharepoint.spregionalsettings.timezones.aspx
$LocaleId=1031                    # list of localeIDs: https://www.pdshop.com/locale-id-lcid-code-list-currency-date-kb-21/
$WorkDayStartHour=480             # list of WorkDayStartHours: https://docs.microsoft.com/en-us/previous-versions/office/sharepoint-csom/jj171629(v=office.15)
$WorkDayEndHour=1020              # list of WorkDayEndHours: https://docs.microsoft.com/en-us/previous-versions/office/sharepoint-csom/jj171629(v=office.15)
$FirstDayOfWeek=1                 # list of FirstDayofWeek: https://docs.microsoft.com/en-us/previous-versions/office/sharepoint-csom/jj169347(v=office.15)
$Time24=$True                     # true or false
$CalendarType=1                   # list of CalendarType: https://docs.microsoft.com/en-us/previous-versions/office/sharepoint-csom/ee543260(v=office.15)
$AlternateCalendarType=0          # None alternative calendar
$WorkDays=62                      # list of WorkDays: https://docs.microsoft.com/en-us/previous-versions/office/sharepoint-csom/jj167337(v=office.15)

$sites=Get-SPOSite

foreach($site in $sites)
{
    Write-Host $site.Url
    Set-SPOUser -site $site -LoginName $Username -IsSiteCollectionAdmin $True
    Set-SPoSitesRegionalSettings -Username $Username -AdminPassword $AdminPassword -Url $site.Url -TimeZoneID $TimeZoneID -LocaleID $LocaleId -WorkDayStartHour $WorkDayStartHour -WorkDayEndHour $WorkDayEndHour -FirstDayOfWeek $FirstDayOfWeek -Time24 $Time24 -CalendarType $CalendarType -WorkDays $WorkDays -AlternateCalendarType $AlternateCalendarType
}

$SiteScript = (Get-Content "C:\Temp\RegionalSettingsAustria.json" -Raw | Add-SPOSiteScript -Title "Applies AT regional settings" -Description "Applies AT regional settings")
Add-SPOSiteDesign -Title "Applies AT regional settings" -WebTemplate "64" -SiteScripts $SiteScript -Description "Applies AT regional settings" -IsDefault
